@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -44,6 +44,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Set;
 import java.util.stream.Stream;
 
 import static java.lang.invoke.LambdaForm.BasicType;
@@ -84,6 +85,7 @@ class InvokerBytecodeGenerator {
     static final String INVOKER_SUPER_NAME = OBJ;
 
     /** Name of new class */
+    private final String name;
     private final String className;
 
     private final LambdaForm lambdaForm;
@@ -117,16 +119,17 @@ class InvokerBytecodeGenerator {
 
     /** Main constructor; other constructors delegate to this one. */
     private InvokerBytecodeGenerator(LambdaForm lambdaForm, int localsMapSize,
-                                     String className, String invokerName, MethodType invokerType) {
+                                     String name, String invokerName, MethodType invokerType) {
         int p = invokerName.indexOf('.');
         if (p > -1) {
-            className = invokerName.substring(0, p);
+            name = invokerName.substring(0, p);
             invokerName = invokerName.substring(p + 1);
         }
         if (DUMP_CLASS_FILES) {
-            className = makeDumpableClassName(className);
+            name = makeDumpableClassName(name);
         }
-        this.className  = className;
+        this.name = name;
+        this.className = CLASS_PREFIX + name;
         this.lambdaForm = lambdaForm;
         this.invokerName = invokerName;
         this.invokerType = invokerType;
@@ -135,9 +138,9 @@ class InvokerBytecodeGenerator {
     }
 
     /** For generating LambdaForm interpreter entry points. */
-    private InvokerBytecodeGenerator(String className, String invokerName, MethodType invokerType) {
+    private InvokerBytecodeGenerator(String name, String invokerName, MethodType invokerType) {
         this(null, invokerType.parameterCount(),
-             className, invokerName, invokerType);
+             name, invokerName, invokerType);
         MethodType mt = invokerType.erase();
         // Create an array to map name indexes to locals indexes.
         localsMap[0] = 0; // localsMap has at least one element
@@ -149,15 +152,15 @@ class InvokerBytecodeGenerator {
     }
 
     /** For generating customized code for a single LambdaForm. */
-    private InvokerBytecodeGenerator(String className, LambdaForm form, MethodType invokerType) {
-        this(className, form.lambdaName(), form, invokerType);
+    private InvokerBytecodeGenerator(String name, LambdaForm form, MethodType invokerType) {
+        this(name, form.lambdaName(), form, invokerType);
     }
 
     /** For generating customized code for a single LambdaForm. */
-    InvokerBytecodeGenerator(String className, String invokerName,
+    InvokerBytecodeGenerator(String name, String invokerName,
             LambdaForm form, MethodType invokerType) {
         this(form, form.names.length,
-             className, invokerName, invokerType);
+             name, invokerName, invokerType);
         // Create an array to map name indexes to locals indexes.
         Name[] names = form.names;
         for (int i = 0, index = 0; i < localsMap.length; i++) {
@@ -195,11 +198,12 @@ class InvokerBytecodeGenerator {
 
     private void maybeDump(final byte[] classFile) {
         if (DUMP_CLASS_FILES) {
-            maybeDump(CLASS_PREFIX + className, classFile);
+            maybeDump(className, classFile);
         }
     }
 
     // Also used from BoundMethodHandle
+    @SuppressWarnings("removal")
     static void maybeDump(final String className, final byte[] classFile) {
         if (DUMP_CLASS_FILES) {
             java.security.AccessController.doPrivileged(
@@ -231,7 +235,7 @@ class InvokerBytecodeGenerator {
         }
         String sfx = ctr.toString();
         while (sfx.length() < 3)
-            sfx = "0"+sfx;
+            sfx = "0" + sfx;
         className += sfx;
         return className;
     }
@@ -265,28 +269,42 @@ class InvokerBytecodeGenerator {
             desc = "Ljava/lang/Object;";
         }
 
-        Class<?> c = arg.getClass();
-        while (c.isArray()) {
-            c = c.getComponentType();
-        }
         // unique static variable name
-        String name = "_DATA_" + c.getSimpleName() + "_" + classData.size();
+        String name;
+        if (DUMP_CLASS_FILES) {
+            Class<?> c = arg.getClass();
+            while (c.isArray()) {
+                c = c.getComponentType();
+            }
+            name = "_DATA_" + c.getSimpleName() + "_" + classData.size();
+        } else {
+            name = "_D_" + classData.size();
+        }
         ClassData cd = new ClassData(name, desc, arg);
         classData.add(cd);
-        return cd.name();
+        return name;
     }
 
     List<Object> classDataValues() {
-        Object[] data = new Object[classData.size()];
-        for (int i = 0; i < classData.size(); i++) {
-            data[i] = classData.get(i).value;
-        }
-        return List.of(data);
+        final List<ClassData> cd = classData;
+        return switch(cd.size()) {
+            case 0 -> List.of();
+            case 1 -> List.of(cd.get(0).value);
+            case 2 -> List.of(cd.get(0).value, cd.get(1).value);
+            case 3 -> List.of(cd.get(0).value, cd.get(1).value, cd.get(2).value);
+            case 4 -> List.of(cd.get(0).value, cd.get(1).value, cd.get(2).value, cd.get(3).value);
+            default -> {
+                Object[] data = new Object[classData.size()];
+                for (int i = 0; i < classData.size(); i++) {
+                    data[i] = classData.get(i).value;
+                }
+                yield List.of(data);
+            }
+        };
     }
 
     private static String debugString(Object arg) {
-        if (arg instanceof MethodHandle) {
-            MethodHandle mh = (MethodHandle) arg;
+        if (arg instanceof MethodHandle mh) {
             MemberName member = mh.internalMemberName();
             if (member != null)
                 return member.toString();
@@ -295,26 +313,11 @@ class InvokerBytecodeGenerator {
         return arg.toString();
     }
 
-    /**
-     * Extract the number of constant pool entries from a given class file.
-     *
-     * @param classFile the bytes of the class file in question.
-     * @return the number of entries in the constant pool.
-     */
-    private static int getConstantPoolSize(byte[] classFile) {
-        // The first few bytes:
-        // u4 magic;
-        // u2 minor_version;
-        // u2 major_version;
-        // u2 constant_pool_count;
-        return ((classFile[8] & 0xFF) << 8) | (classFile[9] & 0xFF);
-    }
-
     /**
      * Extract the MemberName of a newly-defined method.
      */
     private MemberName loadMethod(byte[] classFile) {
-        Class<?> invokerClass = LOOKUP.makeHiddenClassDefiner(className(), classFile)
+        Class<?> invokerClass = LOOKUP.makeHiddenClassDefiner(className, classFile, Set.of())
                                       .defineClass(true, classDataValues());
         return resolveInvokerMember(invokerClass, invokerName, invokerType);
     }
@@ -322,7 +325,9 @@ class InvokerBytecodeGenerator {
     private static MemberName resolveInvokerMember(Class<?> invokerClass, String name, MethodType type) {
         MemberName member = new MemberName(invokerClass, name, type, REF_invokeStatic);
         try {
-            member = MEMBERNAME_FACTORY.resolveOrFail(REF_invokeStatic, member, HOST_CLASS, ReflectiveOperationException.class);
+            member = MEMBERNAME_FACTORY.resolveOrFail(REF_invokeStatic, member,
+                                                      HOST_CLASS, LM_TRUSTED,
+                                                      ReflectiveOperationException.class);
         } catch (ReflectiveOperationException e) {
             throw newInternalError(e);
         }
@@ -336,9 +341,9 @@ class InvokerBytecodeGenerator {
         final int NOT_ACC_PUBLIC = 0;  // not ACC_PUBLIC
         ClassWriter cw = new ClassWriter(ClassWriter.COMPUTE_MAXS + ClassWriter.COMPUTE_FRAMES);
         setClassWriter(cw);
-        cw.visit(Opcodes.V1_8, NOT_ACC_PUBLIC + Opcodes.ACC_FINAL + Opcodes.ACC_SUPER,
-                CLASS_PREFIX + className, null, INVOKER_SUPER_NAME, null);
-        cw.visitSource(SOURCE_PREFIX + className, null);
+        cw.visit(CLASSFILE_VERSION, NOT_ACC_PUBLIC + Opcodes.ACC_FINAL + Opcodes.ACC_SUPER,
+                className, null, INVOKER_SUPER_NAME, null);
+        cw.visitSource(SOURCE_PREFIX + name, null);
         return cw;
     }
 
@@ -355,14 +360,6 @@ class InvokerBytecodeGenerator {
         mv.visitEnd();
     }
 
-    private String className() {
-        return CLASS_PREFIX + className;
-    }
-
-    private void clinit() {
-        clinit(cw, className(), classData);
-    }
-
     /*
      * <clinit> to initialize the static final fields with the live class data
      * LambdaForms can't use condy due to bootstrapping issue.
@@ -380,7 +377,7 @@ class InvokerBytecodeGenerator {
         MethodVisitor mv = cw.visitMethod(Opcodes.ACC_STATIC, "<clinit>", "()V", null, null);
         mv.visitCode();
         mv.visitLdcInsn(Type.getType("L" + className + ";"));
-        mv.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/invoke/MethodHandleNatives",
+        mv.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/invoke/MethodHandles",
                            "classData", "(Ljava/lang/Class;)Ljava/lang/Object;", false);
         // we should optimize one single element case that does not need to create a List
         mv.visitTypeInsn(Opcodes.CHECKCAST, "java/util/List");
@@ -496,15 +493,14 @@ class InvokerBytecodeGenerator {
     }
 
     private int loadInsnOpcode(BasicType type) throws InternalError {
-        switch (type) {
-            case I_TYPE: return Opcodes.ILOAD;
-            case J_TYPE: return Opcodes.LLOAD;
-            case F_TYPE: return Opcodes.FLOAD;
-            case D_TYPE: return Opcodes.DLOAD;
-            case L_TYPE: return Opcodes.ALOAD;
-            default:
-                throw new InternalError("unknown type: " + type);
-        }
+        return switch (type) {
+            case I_TYPE -> Opcodes.ILOAD;
+            case J_TYPE -> Opcodes.LLOAD;
+            case F_TYPE -> Opcodes.FLOAD;
+            case D_TYPE -> Opcodes.DLOAD;
+            case L_TYPE -> Opcodes.ALOAD;
+            default -> throw new InternalError("unknown type: " + type);
+        };
     }
     private void emitAloadInsn(int index) {
         emitLoadInsn(L_TYPE, index);
@@ -516,50 +512,48 @@ class InvokerBytecodeGenerator {
     }
 
     private int storeInsnOpcode(BasicType type) throws InternalError {
-        switch (type) {
-            case I_TYPE: return Opcodes.ISTORE;
-            case J_TYPE: return Opcodes.LSTORE;
-            case F_TYPE: return Opcodes.FSTORE;
-            case D_TYPE: return Opcodes.DSTORE;
-            case L_TYPE: return Opcodes.ASTORE;
-            default:
-                throw new InternalError("unknown type: " + type);
-        }
+        return switch (type) {
+            case I_TYPE -> Opcodes.ISTORE;
+            case J_TYPE -> Opcodes.LSTORE;
+            case F_TYPE -> Opcodes.FSTORE;
+            case D_TYPE -> Opcodes.DSTORE;
+            case L_TYPE -> Opcodes.ASTORE;
+            default -> throw new InternalError("unknown type: " + type);
+        };
     }
     private void emitAstoreInsn(int index) {
         emitStoreInsn(L_TYPE, index);
     }
 
     private byte arrayTypeCode(Wrapper elementType) {
-        switch (elementType) {
-            case BOOLEAN: return Opcodes.T_BOOLEAN;
-            case BYTE:    return Opcodes.T_BYTE;
-            case CHAR:    return Opcodes.T_CHAR;
-            case SHORT:   return Opcodes.T_SHORT;
-            case INT:     return Opcodes.T_INT;
-            case LONG:    return Opcodes.T_LONG;
-            case FLOAT:   return Opcodes.T_FLOAT;
-            case DOUBLE:  return Opcodes.T_DOUBLE;
-            case OBJECT:  return 0; // in place of Opcodes.T_OBJECT
-            default:      throw new InternalError();
-        }
+        return (byte) switch (elementType) {
+            case BOOLEAN -> Opcodes.T_BOOLEAN;
+            case BYTE    -> Opcodes.T_BYTE;
+            case CHAR    -> Opcodes.T_CHAR;
+            case SHORT   -> Opcodes.T_SHORT;
+            case INT     -> Opcodes.T_INT;
+            case LONG    -> Opcodes.T_LONG;
+            case FLOAT   -> Opcodes.T_FLOAT;
+            case DOUBLE  -> Opcodes.T_DOUBLE;
+            case OBJECT  -> 0; // in place of Opcodes.T_OBJECT
+            default -> throw new InternalError();
+        };
     }
 
     private int arrayInsnOpcode(byte tcode, int aaop) throws InternalError {
         assert(aaop == Opcodes.AASTORE || aaop == Opcodes.AALOAD);
-        int xas;
-        switch (tcode) {
-            case Opcodes.T_BOOLEAN: xas = Opcodes.BASTORE; break;
-            case Opcodes.T_BYTE:    xas = Opcodes.BASTORE; break;
-            case Opcodes.T_CHAR:    xas = Opcodes.CASTORE; break;
-            case Opcodes.T_SHORT:   xas = Opcodes.SASTORE; break;
-            case Opcodes.T_INT:     xas = Opcodes.IASTORE; break;
-            case Opcodes.T_LONG:    xas = Opcodes.LASTORE; break;
-            case Opcodes.T_FLOAT:   xas = Opcodes.FASTORE; break;
-            case Opcodes.T_DOUBLE:  xas = Opcodes.DASTORE; break;
-            case 0:                 xas = Opcodes.AASTORE; break;
-            default:      throw new InternalError();
-        }
+        int xas = switch (tcode) {
+            case Opcodes.T_BOOLEAN -> Opcodes.BASTORE;
+            case Opcodes.T_BYTE    -> Opcodes.BASTORE;
+            case Opcodes.T_CHAR    -> Opcodes.CASTORE;
+            case Opcodes.T_SHORT   -> Opcodes.SASTORE;
+            case Opcodes.T_INT     -> Opcodes.IASTORE;
+            case Opcodes.T_LONG    -> Opcodes.LASTORE;
+            case Opcodes.T_FLOAT   -> Opcodes.FASTORE;
+            case Opcodes.T_DOUBLE  -> Opcodes.DASTORE;
+            case 0                 -> Opcodes.AASTORE;
+            default -> throw new InternalError();
+        };
         return xas - Opcodes.AASTORE + aaop;
     }
 
@@ -631,8 +625,7 @@ class InvokerBytecodeGenerator {
 
     private void emitReferenceCast(Class<?> cls, Object arg) {
         Name writeBack = null;  // local to write back result
-        if (arg instanceof Name) {
-            Name n = (Name) arg;
+        if (arg instanceof Name n) {
             if (lambdaForm.useCount(n) > 1) {
                 // This guy gets used more than once.
                 writeBack = n;
@@ -645,7 +638,7 @@ class InvokerBytecodeGenerator {
             String sig = getInternalName(cls);
             mv.visitTypeInsn(Opcodes.CHECKCAST, sig);
         } else {
-            mv.visitFieldInsn(Opcodes.GETSTATIC, className(), classData(cls), "Ljava/lang/Class;");
+            mv.visitFieldInsn(Opcodes.GETSTATIC, className, classData(cls), "Ljava/lang/Class;");
             mv.visitInsn(Opcodes.SWAP);
             mv.visitMethodInsn(Opcodes.INVOKEVIRTUAL, CLS, "cast", LL_SIG, false);
             if (Object[].class.isAssignableFrom(cls))
@@ -663,17 +656,15 @@ class InvokerBytecodeGenerator {
      * Emits an actual return instruction conforming to the given return type.
      */
     private void emitReturnInsn(BasicType type) {
-        int opcode;
-        switch (type) {
-        case I_TYPE:  opcode = Opcodes.IRETURN;  break;
-        case J_TYPE:  opcode = Opcodes.LRETURN;  break;
-        case F_TYPE:  opcode = Opcodes.FRETURN;  break;
-        case D_TYPE:  opcode = Opcodes.DRETURN;  break;
-        case L_TYPE:  opcode = Opcodes.ARETURN;  break;
-        case V_TYPE:  opcode = Opcodes.RETURN;   break;
-        default:
-            throw new InternalError("unknown return type: " + type);
-        }
+        int opcode = switch (type) {
+            case I_TYPE -> Opcodes.IRETURN;
+            case J_TYPE -> Opcodes.LRETURN;
+            case F_TYPE -> Opcodes.FRETURN;
+            case D_TYPE -> Opcodes.DRETURN;
+            case L_TYPE -> Opcodes.ARETURN;
+            case V_TYPE -> Opcodes.RETURN;
+            default -> throw new InternalError("unknown return type: " + type);
+        };
         mv.visitInsn(opcode);
     }
 
@@ -692,12 +683,10 @@ class InvokerBytecodeGenerator {
     }
 
     private static MemberName resolveFrom(String name, MethodType type, Class<?> holder) {
+        assert(!UNSAFE.shouldBeInitialized(holder)) : holder + "not initialized";
         MemberName member = new MemberName(holder, name, type, REF_invokeStatic);
-        MemberName resolvedMember = MemberName.getFactory().resolveOrNull(REF_invokeStatic, member, holder);
-        if (TRACE_RESOLVE) {
-            System.out.println("[LF_RESOLVE] " + holder.getName() + " " + name + " " +
-                    shortenSignature(basicTypeSignature(type)) + (resolvedMember != null ? " (success)" : " (fail)") );
-        }
+        MemberName resolvedMember = MemberName.getFactory().resolveOrNull(REF_invokeStatic, member, holder, LM_TRUSTED);
+        traceLambdaForm(name, type, holder, resolvedMember);
         return resolvedMember;
     }
 
@@ -723,7 +712,7 @@ class InvokerBytecodeGenerator {
             case LINK_TO_CALL_SITE:         // fall-through
             case LINK_TO_TARGET_METHOD:     // fall-through
             case GENERIC_INVOKER:           // fall-through
-            case GENERIC_LINKER:            return resolveFrom(name, invokerType.basicType(), Invokers.Holder.class);
+            case GENERIC_LINKER:            return resolveFrom(name, invokerType, Invokers.Holder.class);
             case GET_REFERENCE:             // fall-through
             case GET_BOOLEAN:               // fall-through
             case GET_BYTE:                  // fall-through
@@ -804,7 +793,7 @@ class InvokerBytecodeGenerator {
     private byte[] generateCustomizedCodeBytes() {
         classFilePrologue();
         addMethod();
-        clinit();
+        clinit(cw, className, classData);
         bogusMethod(lambdaForm);
 
         final byte[] classFile = toByteArray();
@@ -839,7 +828,7 @@ class InvokerBytecodeGenerator {
             // receiver MethodHandle (at slot #0) with an embedded constant and use it instead.
             // It enables more efficient code generation in some situations, since embedded constants
             // are compile-time constants for JIT compiler.
-            mv.visitFieldInsn(Opcodes.GETSTATIC, className(), classData(lambdaForm.customized), MH_SIG);
+            mv.visitFieldInsn(Opcodes.GETSTATIC, className, classData(lambdaForm.customized), MH_SIG);
             mv.visitTypeInsn(Opcodes.CHECKCAST, MH);
             assert(checkActualReceiver()); // expects MethodHandle on top of the stack
             mv.visitVarInsn(Opcodes.ASTORE, localsMap[0]);
@@ -875,18 +864,17 @@ class InvokerBytecodeGenerator {
                     onStack = emitTryFinally(i);
                     i += 2; // jump to the end of the TF idiom
                     continue;
+                case TABLE_SWITCH:
+                    assert lambdaForm.isTableSwitch(i);
+                    int numCases = (Integer) name.function.intrinsicData();
+                    onStack = emitTableSwitch(i, numCases);
+                    i += 2; // jump to the end of the TS idiom
+                    continue;
                 case LOOP:
                     assert lambdaForm.isLoop(i);
                     onStack = emitLoop(i);
                     i += 2; // jump to the end of the LOOP idiom
                     continue;
-                case NEW_ARRAY:
-                    Class<?> rtype = name.function.methodType().returnType();
-                    if (isStaticallyNameable(rtype)) {
-                        emitNewArray(name);
-                        continue;
-                    }
-                    break;
                 case ARRAY_LOAD:
                     emitArrayLoad(name);
                     continue;
@@ -937,6 +925,9 @@ class InvokerBytecodeGenerator {
         }
     }
 
+    /**
+     * The BytecodeGenerationException.
+     */
     @SuppressWarnings("serial")
     static final class BytecodeGenerationException extends RuntimeException {
         BytecodeGenerationException(Exception cause) {
@@ -969,7 +960,7 @@ class InvokerBytecodeGenerator {
             // push receiver
             MethodHandle target = name.function.resolvedHandle();
             assert(target != null) : name.exprString();
-            mv.visitFieldInsn(Opcodes.GETSTATIC, className(), classData(target), MH_SIG);
+            mv.visitFieldInsn(Opcodes.GETSTATIC, className, classData(target), MH_SIG);
             emitReferenceCast(MethodHandle.class, target);
         } else {
             // load receiver
@@ -988,7 +979,7 @@ class InvokerBytecodeGenerator {
         mv.visitMethodInsn(Opcodes.INVOKEVIRTUAL, MH, "invokeBasic", type.basicType().toMethodDescriptorString(), false);
     }
 
-    private static Class<?>[] STATICALLY_INVOCABLE_PACKAGES = {
+    private static final Class<?>[] STATICALLY_INVOCABLE_PACKAGES = {
         // Sample classes from each package we are willing to bind to statically:
         java.lang.Object.class,
         java.util.Arrays.class,
@@ -1027,8 +1018,6 @@ class InvokerBytecodeGenerator {
             return false;  // not on BCP
         if (cls.isHidden())
             return false;
-        if (ReflectUtil.isVMAnonymousClass(cls))   // FIXME: Unsafe::defineAnonymousClass to be removed
-            return false;
         if (!isStaticallyInvocableType(member.getMethodOrFieldType()))
             return false;
         if (!member.isPrivate() && VerifyAccess.isSamePackage(MethodHandle.class, cls))
@@ -1060,8 +1049,6 @@ class InvokerBytecodeGenerator {
             return true;  // int[].class, for example
         if (cls.isHidden())
             return false;
-        if (ReflectUtil.isVMAnonymousClass(cls))   // FIXME: Unsafe::defineAnonymousClass to be removed
-            return false;
         // could use VerifyAccess.isClassAccessible but the following is a safe approximation
         if (cls.getClassLoader() != Object.class.getClassLoader())
             return false;
@@ -1120,43 +1107,6 @@ class InvokerBytecodeGenerator {
         }
     }
 
-    void emitNewArray(Name name) throws InternalError {
-        Class<?> rtype = name.function.methodType().returnType();
-        if (name.arguments.length == 0) {
-            // The array will be a constant.
-            Object emptyArray;
-            try {
-                emptyArray = name.function.resolvedHandle().invoke();
-            } catch (Throwable ex) {
-                throw uncaughtException(ex);
-            }
-            assert(java.lang.reflect.Array.getLength(emptyArray) == 0);
-            assert(emptyArray.getClass() == rtype);  // exact typing
-            mv.visitFieldInsn(Opcodes.GETSTATIC, className(), classData(emptyArray), "Ljava/lang/Object;");
-            emitReferenceCast(rtype, emptyArray);
-            return;
-        }
-        Class<?> arrayElementType = rtype.getComponentType();
-        assert(arrayElementType != null);
-        emitIconstInsn(name.arguments.length);
-        int xas = Opcodes.AASTORE;
-        if (!arrayElementType.isPrimitive()) {
-            mv.visitTypeInsn(Opcodes.ANEWARRAY, getInternalName(arrayElementType));
-        } else {
-            byte tc = arrayTypeCode(Wrapper.forPrimitiveType(arrayElementType));
-            xas = arrayInsnOpcode(tc, xas);
-            mv.visitIntInsn(Opcodes.NEWARRAY, tc);
-        }
-        // store arguments
-        for (int i = 0; i < name.arguments.length; i++) {
-            mv.visitInsn(Opcodes.DUP);
-            emitIconstInsn(i);
-            emitPushArgument(name, i);
-            mv.visitInsn(xas);
-        }
-        // the array is left on the stack
-        assertStaticType(rtype, name);
-    }
     int refKindOpcode(byte refKind) {
         switch (refKind) {
         case REF_invokeVirtual:      return Opcodes.INVOKEVIRTUAL;
@@ -1432,17 +1382,63 @@ class InvokerBytecodeGenerator {
     }
 
     private static int popInsnOpcode(BasicType type) {
-        switch (type) {
-            case I_TYPE:
-            case F_TYPE:
-            case L_TYPE:
-                return Opcodes.POP;
-            case J_TYPE:
-            case D_TYPE:
-                return Opcodes.POP2;
-            default:
-                throw new InternalError("unknown type: " + type);
+        return switch (type) {
+            case I_TYPE, F_TYPE, L_TYPE -> Opcodes.POP;
+            case J_TYPE, D_TYPE         -> Opcodes.POP2;
+            default -> throw new InternalError("unknown type: " + type);
+        };
+    }
+
+    private Name emitTableSwitch(int pos, int numCases) {
+        Name args    = lambdaForm.names[pos];
+        Name invoker = lambdaForm.names[pos + 1];
+        Name result  = lambdaForm.names[pos + 2];
+
+        Class<?> returnType = result.function.resolvedHandle().type().returnType();
+        MethodType caseType = args.function.resolvedHandle().type()
+            .dropParameterTypes(0, 1) // drop collector
+            .changeReturnType(returnType);
+        String caseDescriptor = caseType.basicType().toMethodDescriptorString();
+
+        emitPushArgument(invoker, 2); // push cases
+        mv.visitFieldInsn(Opcodes.GETFIELD, "java/lang/invoke/MethodHandleImpl$CasesHolder", "cases",
+            "[Ljava/lang/invoke/MethodHandle;");
+        int casesLocal = extendLocalsMap(new Class<?>[] { MethodHandle[].class });
+        emitStoreInsn(L_TYPE, casesLocal);
+
+        Label endLabel = new Label();
+        Label defaultLabel = new Label();
+        Label[] caseLabels = new Label[numCases];
+        for (int i = 0; i < caseLabels.length; i++) {
+            caseLabels[i] = new Label();
         }
+
+        emitPushArgument(invoker, 0); // push switch input
+        mv.visitTableSwitchInsn(0, numCases - 1, defaultLabel, caseLabels);
+
+        mv.visitLabel(defaultLabel);
+        emitPushArgument(invoker, 1); // push default handle
+        emitPushArguments(args, 1); // again, skip collector
+        mv.visitMethodInsn(Opcodes.INVOKEVIRTUAL, MH, "invokeBasic", caseDescriptor, false);
+        mv.visitJumpInsn(Opcodes.GOTO, endLabel);
+
+        for (int i = 0; i < numCases; i++) {
+            mv.visitLabel(caseLabels[i]);
+            // Load the particular case:
+            emitLoadInsn(L_TYPE, casesLocal);
+            emitIconstInsn(i);
+            mv.visitInsn(Opcodes.AALOAD);
+
+            // invoke it:
+            emitPushArguments(args, 1); // again, skip collector
+            mv.visitMethodInsn(Opcodes.INVOKEVIRTUAL, MH, "invokeBasic", caseDescriptor, false);
+
+            mv.visitJumpInsn(Opcodes.GOTO, endLabel);
+        }
+
+        mv.visitLabel(endLabel);
+
+        return result;
     }
 
     /**
@@ -1660,14 +1656,14 @@ class InvokerBytecodeGenerator {
     }
 
     private void emitZero(BasicType type) {
-        switch (type) {
-            case I_TYPE: mv.visitInsn(Opcodes.ICONST_0); break;
-            case J_TYPE: mv.visitInsn(Opcodes.LCONST_0); break;
-            case F_TYPE: mv.visitInsn(Opcodes.FCONST_0); break;
-            case D_TYPE: mv.visitInsn(Opcodes.DCONST_0); break;
-            case L_TYPE: mv.visitInsn(Opcodes.ACONST_NULL); break;
-            default: throw new InternalError("unknown type: " + type);
-        }
+        mv.visitInsn(switch (type) {
+            case I_TYPE -> Opcodes.ICONST_0;
+            case J_TYPE -> Opcodes.LCONST_0;
+            case F_TYPE -> Opcodes.FCONST_0;
+            case D_TYPE -> Opcodes.DCONST_0;
+            case L_TYPE -> Opcodes.ACONST_NULL;
+            default -> throw new InternalError("unknown type: " + type);
+        });
     }
 
     private void emitPushArguments(Name args, int start) {
@@ -1685,17 +1681,18 @@ class InvokerBytecodeGenerator {
 
     private void emitPushArgument(Class<?> ptype, Object arg) {
         BasicType bptype = basicType(ptype);
-        if (arg instanceof Name) {
-            Name n = (Name) arg;
+        if (arg instanceof Name n) {
             emitLoadInsn(n.type, n.index());
             emitImplicitConversion(n.type, ptype, n);
-        } else if ((arg == null || arg instanceof String) && bptype == L_TYPE) {
-            emitConst(arg);
+        } else if (arg == null && bptype == L_TYPE) {
+            mv.visitInsn(Opcodes.ACONST_NULL);
+        } else if (arg instanceof String && bptype == L_TYPE) {
+            mv.visitLdcInsn(arg);
         } else {
             if (Wrapper.isWrapperType(arg.getClass()) && bptype != L_TYPE) {
                 emitConst(arg);
             } else {
-                mv.visitFieldInsn(Opcodes.GETSTATIC, className(), classData(arg), "Ljava/lang/Object;");
+                mv.visitFieldInsn(Opcodes.GETSTATIC, className, classData(arg), "Ljava/lang/Object;");
                 emitImplicitConversion(L_TYPE, ptype, arg);
             }
         }
@@ -1774,30 +1771,28 @@ class InvokerBytecodeGenerator {
                 // cast to {long,float,double} - this is verbose
                 boolean error = false;
                 switch (from) {
-                case LONG:
-                    switch (to) {
-                    case FLOAT:   mv.visitInsn(Opcodes.L2F);  break;
-                    case DOUBLE:  mv.visitInsn(Opcodes.L2D);  break;
-                    default:      error = true;               break;
+                    case LONG -> {
+                        switch (to) {
+                            case FLOAT  -> mv.visitInsn(Opcodes.L2F);
+                            case DOUBLE -> mv.visitInsn(Opcodes.L2D);
+                            default -> error = true;
+                        }
                     }
-                    break;
-                case FLOAT:
-                    switch (to) {
-                    case LONG :   mv.visitInsn(Opcodes.F2L);  break;
-                    case DOUBLE:  mv.visitInsn(Opcodes.F2D);  break;
-                    default:      error = true;               break;
+                    case FLOAT -> {
+                        switch (to) {
+                            case LONG   -> mv.visitInsn(Opcodes.F2L);
+                            case DOUBLE -> mv.visitInsn(Opcodes.F2D);
+                            default -> error = true;
+                        }
                     }
-                    break;
-                case DOUBLE:
-                    switch (to) {
-                    case LONG :   mv.visitInsn(Opcodes.D2L);  break;
-                    case FLOAT:   mv.visitInsn(Opcodes.D2F);  break;
-                    default:      error = true;               break;
+                    case DOUBLE -> {
+                        switch (to) {
+                            case LONG  -> mv.visitInsn(Opcodes.D2L);
+                            case FLOAT -> mv.visitInsn(Opcodes.D2F);
+                            default -> error = true;
+                        }
                     }
-                    break;
-                default:
-                    error = true;
-                    break;
+                    default -> error = true;
                 }
                 if (error) {
                     throw new IllegalStateException("unhandled prim cast: " + from + "2" + to);
@@ -1826,10 +1821,10 @@ class InvokerBytecodeGenerator {
 
     private void emitX2I(Wrapper type) {
         switch (type) {
-        case LONG:    mv.visitInsn(Opcodes.L2I);  break;
-        case FLOAT:   mv.visitInsn(Opcodes.F2I);  break;
-        case DOUBLE:  mv.visitInsn(Opcodes.D2I);  break;
-        default:      throw new InternalError("unknown type: " + type);
+            case LONG -> mv.visitInsn(Opcodes.L2I);
+            case FLOAT -> mv.visitInsn(Opcodes.F2I);
+            case DOUBLE -> mv.visitInsn(Opcodes.D2I);
+            default -> throw new InternalError("unknown type: " + type);
         }
     }
 
@@ -1887,7 +1882,7 @@ class InvokerBytecodeGenerator {
         emitReturnInsn(basicType(rtype));
 
         methodEpilogue();
-        clinit();
+        clinit(cw, className, classData);
         bogusMethod(invokerType);
 
         final byte[] classFile = cw.toByteArray();
@@ -1956,7 +1951,7 @@ class InvokerBytecodeGenerator {
         emitReturnInsn(L_TYPE);  // NOTE: NamedFunction invokers always return a reference value.
 
         methodEpilogue();
-        clinit();
+        clinit(cw, className, classData);
         bogusMethod(dstType);
 
         final byte[] classFile = cw.toByteArray();
