@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2001, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,6 +32,7 @@
 package sun.security.krb5.internal;
 
 import sun.security.krb5.*;
+
 import java.io.IOException;
 import java.util.LinkedList;
 import java.util.List;
@@ -45,33 +46,58 @@ public class CredentialsUtil {
 
     private static boolean DEBUG = sun.security.krb5.internal.Krb5.DEBUG;
 
+    private static enum S4U2Type {
+        NONE, SELF, PROXY
+    }
+
     /**
      * Used by a middle server to acquire credentials on behalf of a
-     * client to itself using the S4U2self extension.
-     * @param client the client to impersonate
-     * @param ccreds the TGT of the middle service
-     * @return the new creds (cname=client, sname=middle)
+     * user to itself using the S4U2self extension.
+     * @param user the user to impersonate
+     * @param middleTGT the TGT of the middle service
+     * @return the new creds (cname=user, sname=middle)
      */
-    public static Credentials acquireS4U2selfCreds(PrincipalName client,
-            Credentials ccreds) throws KrbException, IOException {
-        String uRealm = client.getRealmString();
-        String localRealm = ccreds.getClient().getRealmString();
+    public static Credentials acquireS4U2selfCreds(PrincipalName user,
+            Credentials middleTGT) throws KrbException, IOException {
+        PrincipalName sname = middleTGT.getClient();
+        String uRealm = user.getRealmString();
+        String localRealm = sname.getRealmString();
         if (!uRealm.equals(localRealm)) {
-            // TODO: we do not support kerberos referral now
-            throw new KrbException("Cross realm impersonation not supported");
+            // Referrals will be required because the middle service
+            // and the user impersonated are on different realms.
+            if (Config.DISABLE_REFERRALS) {
+                throw new KrbException("Cross-realm S4U2Self request not" +
+                        " possible when referrals are disabled.");
+            }
+            if (middleTGT.getClientAlias() != null) {
+                // If the name was canonicalized, the user pick
+                // has preference. This gives the possibility of
+                // using FQDNs that KDCs may use to return referrals.
+                // I.e.: a SVC/host.realm-2.com@REALM-1.COM name
+                // may be used by REALM-1.COM KDC to return a
+                // referral to REALM-2.COM.
+                sname = middleTGT.getClientAlias();
+            }
+            sname = new PrincipalName(sname.getNameType(),
+                    sname.getNameStrings(), new Realm(uRealm));
         }
-        if (!ccreds.isForwardable()) {
-            throw new KrbException("S4U2self needs a FORWARDABLE ticket");
-        }
-        Credentials creds = serviceCreds(KDCOptions.with(KDCOptions.FORWARDABLE),
-                ccreds, ccreds.getClient(), ccreds.getClient(), null,
-                new PAData[] {new PAData(Krb5.PA_FOR_USER,
-                        new PAForUserEnc(client,
-                            ccreds.getSessionKey()).asn1Encode())});
-        if (!creds.getClient().equals(client)) {
+        Credentials creds = serviceCreds(
+                KDCOptions.with(KDCOptions.FORWARDABLE),
+                middleTGT, middleTGT.getClient(), sname, user,
+                null, new PAData[] {
+                        new PAData(Krb5.PA_FOR_USER,
+                                new PAForUserEnc(user,
+                                        middleTGT.getSessionKey()).asn1Encode()),
+                        new PAData(Krb5.PA_PAC_OPTIONS,
+                                new PaPacOptions()
+                                        .setResourceBasedConstrainedDelegation(true)
+                                        .setClaims(true)
+                                        .asn1Encode())
+                        }, S4U2Type.SELF);
+        if (!creds.getClient().equals(user)) {
             throw new KrbException("S4U2self request not honored by KDC");
         }
-        if (!creds.isForwardable()) {
+        if (!creds.isForwardable() && !Credentials.S4U2PROXY_ACCEPT_NON_FORWARDABLE) {
             throw new KrbException("S4U2self ticket must be FORWARDABLE");
         }
         return creds;
@@ -81,18 +107,39 @@ public class CredentialsUtil {
      * Used by a middle server to acquire a service ticket to a backend
      * server using the S4U2proxy extension.
      * @param backend the name of the backend service
-     * @param second the client's service ticket to the middle server
-     * @param ccreds the TGT of the middle server
-     * @return the creds (cname=client, sname=backend)
+     * @param userCreds containing the user's service ticket to the middle server
+     * @param middleTGT the TGT of the middle server
+     * @return the creds (cname=user, sname=backend)
      */
     public static Credentials acquireS4U2proxyCreds(
-                String backend, Ticket second,
-                PrincipalName client, Credentials ccreds)
+                String backend, Credentials userCreds,
+                PrincipalName client, Credentials middleTGT)
             throws KrbException, IOException {
+        PrincipalName backendPrincipal = new PrincipalName(backend);
+        String backendRealm = backendPrincipal.getRealmString();
+        String localRealm = middleTGT.getClient().getRealmString();
+        if (!backendRealm.equals(localRealm)) {
+            // The middle service and the backend service are on
+            // different realms, so referrals will be required.
+            if (Config.DISABLE_REFERRALS) {
+                throw new KrbException("Cross-realm S4U2Proxy request not" +
+                        " possible when referrals are disabled.");
+            }
+            backendPrincipal = new PrincipalName(
+                    backendPrincipal.getNameType(),
+                    backendPrincipal.getNameStrings(),
+                    new Realm(localRealm));
+        }
         Credentials creds = serviceCreds(KDCOptions.with(
                 KDCOptions.CNAME_IN_ADDL_TKT, KDCOptions.FORWARDABLE),
-                ccreds, ccreds.getClient(), new PrincipalName(backend),
-                new Ticket[] {second}, null);
+                middleTGT, middleTGT.getClient(), backendPrincipal, null,
+                userCreds, new PAData[] {
+                        new PAData(Krb5.PA_PAC_OPTIONS,
+                                new PaPacOptions()
+                                        .setResourceBasedConstrainedDelegation(true)
+                                        .setClaims(true)
+                                        .asn1Encode())
+                        }, S4U2Type.PROXY);
         if (!creds.getClient().equals(client)) {
             throw new KrbException("S4U2proxy request not honored by KDC");
         }
@@ -108,28 +155,30 @@ public class CredentialsUtil {
      * from the foreign KDC.
      *
      * @param service the name of service principal
-     * @param ccreds client's initial credential
+     * @param initCreds client's initial credential
      */
     public static Credentials acquireServiceCreds(
-                String service, Credentials ccreds)
+                String service, Credentials initCreds)
             throws KrbException, IOException {
-        PrincipalName sname = new PrincipalName(service,
-                PrincipalName.KRB_NT_SRV_HST);
-        return serviceCreds(sname, ccreds);
+        return serviceCreds(new KDCOptions(), initCreds,
+                initCreds.getClient(),
+                new PrincipalName(service, PrincipalName.KRB_NT_UNKNOWN),
+                null, null,
+                null, S4U2Type.NONE);
     }
 
     /**
      * Gets a TGT to another realm
      * @param localRealm this realm
      * @param serviceRealm the other realm, cannot equals to localRealm
-     * @param ccreds TGT in this realm
+     * @param localTGT TGT in this realm
      * @param okAsDelegate an [out] argument to receive the okAsDelegate
      * property. True only if all realms allow delegation.
      * @return the TGT for the other realm, null if cannot find a path
      * @throws KrbException if something goes wrong
      */
     private static Credentials getTGTforRealm(String localRealm,
-            String serviceRealm, Credentials ccreds, boolean[] okAsDelegate)
+            String serviceRealm, Credentials localTGT, boolean[] okAsDelegate)
             throws KrbException {
 
         // Get a list of realms to traverse
@@ -141,7 +190,7 @@ public class CredentialsUtil {
         String newTgtRealm = null;
 
         okAsDelegate[0] = true;
-        for (cTgt = ccreds, i = 0; i < realms.length;) {
+        for (cTgt = localTGT, i = 0; i < realms.length;) {
             tempService = PrincipalName.tgsService(serviceRealm, realms[i]);
 
             if (DEBUG) {
@@ -258,10 +307,11 @@ public class CredentialsUtil {
     * This method does the real job to request the service credential.
     */
     private static Credentials serviceCreds(
-            PrincipalName service, Credentials ccreds)
+            PrincipalName service, Credentials initCreds)
             throws KrbException, IOException {
-        return serviceCreds(new KDCOptions(), ccreds,
-                ccreds.getClient(), service, null, null);
+        return serviceCreds(new KDCOptions(), initCreds,
+                initCreds.getClient(), service, null, null,
+                null, S4U2Type.NONE);
     }
 
     /*
@@ -273,20 +323,21 @@ public class CredentialsUtil {
     private static Credentials serviceCreds(
             KDCOptions options, Credentials asCreds,
             PrincipalName cname, PrincipalName sname,
-            Ticket[] additionalTickets, PAData[] extraPAs)
+            PrincipalName user, Credentials additionalCreds,
+            PAData[] extraPAs, S4U2Type s4u2Type)
             throws KrbException, IOException {
         if (!Config.DISABLE_REFERRALS) {
             try {
-                return serviceCredsReferrals(options, asCreds,
-                        cname, sname, additionalTickets, extraPAs);
+                return serviceCredsReferrals(options, asCreds, cname, sname,
+                        s4u2Type, user, additionalCreds, extraPAs);
             } catch (KrbException e) {
                 // Server may raise an error if CANONICALIZE is true.
                 // Try CANONICALIZE false.
             }
         }
         return serviceCredsSingle(options, asCreds, cname,
-                asCreds.getClientAlias(), sname, sname, additionalTickets,
-                extraPAs);
+                asCreds.getClientAlias(), sname, sname, s4u2Type,
+                user, additionalCreds, extraPAs);
     }
 
     /*
@@ -296,8 +347,9 @@ public class CredentialsUtil {
     private static Credentials serviceCredsReferrals(
             KDCOptions options, Credentials asCreds,
             PrincipalName cname, PrincipalName sname,
-            Ticket[] additionalTickets, PAData[] extraPAs)
-            throws KrbException, IOException {
+            S4U2Type s4u2Type, PrincipalName user,
+            Credentials additionalCreds, PAData[] extraPAs)
+                    throws KrbException, IOException {
         options = new KDCOptions(options.toBooleanArray());
         options.set(KDCOptions.CANONICALIZE, true);
         PrincipalName cSname = sname;
@@ -308,38 +360,55 @@ public class CredentialsUtil {
         PrincipalName clientAlias = asCreds.getClientAlias();
         while (referrals.size() <= Config.MAX_REFERRALS) {
             ReferralsCache.ReferralCacheEntry ref =
-                    ReferralsCache.get(cname, sname, refSname.getRealmString());
+                    ReferralsCache.get(cname, sname, user,
+                            additionalCreds, refSname.getRealmString());
             String toRealm = null;
             if (ref == null) {
                 creds = serviceCredsSingle(options, asCreds, cname,
-                        clientAlias, refSname, cSname, additionalTickets,
-                        extraPAs);
+                        clientAlias, refSname, cSname, s4u2Type,
+                        user, additionalCreds, extraPAs);
                 PrincipalName server = creds.getServer();
                 if (!refSname.equals(server)) {
                     String[] serverNameStrings = server.getNameStrings();
                     if (serverNameStrings.length == 2 &&
                         serverNameStrings[0].equals(
                                 PrincipalName.TGS_DEFAULT_SRV_NAME) &&
-                        !refSname.getRealmAsString().equals(serverNameStrings[1])) {
+                        !refSname.getRealmAsString().equals(
+                                serverNameStrings[1])) {
                         // Server Name (sname) has the following format:
                         //      krbtgt/TO-REALM.COM@FROM-REALM.COM
-                        ReferralsCache.put(cname, sname, server.getRealmString(),
+                        ReferralsCache.put(cname, sname, user,
+                                additionalCreds, server.getRealmString(),
                                 serverNameStrings[1], creds);
                         toRealm = serverNameStrings[1];
                         isReferral = true;
-                        asCreds = creds;
                     }
                 }
             } else {
+                creds = ref.getCreds();
                 toRealm = ref.getToRealm();
-                asCreds = ref.getCreds();
                 isReferral = true;
             }
             if (isReferral) {
+                if (s4u2Type == S4U2Type.PROXY) {
+                    Credentials[] credsInOut =
+                            new Credentials[] {creds, null};
+                    toRealm = handleS4U2ProxyReferral(asCreds,
+                            credsInOut, sname);
+                    creds = credsInOut[0];
+                    if (additionalCreds == null || credsInOut[1] == null) {
+                        throw new KrbException("Additional tickets expected" +
+                                " for S4U2Proxy.");
+                    }
+                    additionalCreds = credsInOut[1];
+                } else if (s4u2Type == S4U2Type.SELF) {
+                    handleS4U2SelfReferral(extraPAs, user, creds);
+                }
                 if (referrals.contains(toRealm)) {
                     // Referrals loop detected
                     return null;
                 }
+                asCreds = creds;
                 refSname = new PrincipalName(refSname.getNameString(),
                         refSname.getNameType(), toRealm);
                 referrals.add(toRealm);
@@ -362,8 +431,9 @@ public class CredentialsUtil {
             KDCOptions options, Credentials asCreds,
             PrincipalName cname, PrincipalName clientAlias,
             PrincipalName refSname, PrincipalName sname,
-            Ticket[] additionalTickets, PAData[] extraPAs)
-            throws KrbException, IOException {
+            S4U2Type s4u2Type, PrincipalName user,
+            Credentials additionalCreds, PAData[] extraPAs)
+                    throws KrbException, IOException {
         Credentials theCreds = null;
         boolean[] okAsDelegate = new boolean[]{true};
         String[] serverAsCredsNames = asCreds.getServer().getNameStrings();
@@ -389,6 +459,9 @@ public class CredentialsUtil {
                         " serviceCredsSingle: ");
                 Credentials.printDebug(newTgt);
             }
+            if (s4u2Type == S4U2Type.SELF) {
+                handleS4U2SelfReferral(extraPAs, user, newTgt);
+            }
             asCreds = newTgt;
             cname = asCreds.getClient();
         } else if (DEBUG) {
@@ -396,7 +469,7 @@ public class CredentialsUtil {
                     " same realm");
         }
         KrbTgsReq req = new KrbTgsReq(options, asCreds, cname, clientAlias,
-                refSname, sname, additionalTickets, extraPAs);
+                refSname, sname, additionalCreds, extraPAs);
         theCreds = req.sendAndGetCreds();
         if (theCreds != null) {
             if (DEBUG) {
@@ -409,4 +482,76 @@ public class CredentialsUtil {
         }
         return theCreds;
     }
+
+    /**
+     * PA-FOR-USER may need to be regenerated if credentials
+     * change. This may happen when obtaining a TGT for a
+     * different realm or when using a referral TGT.
+     */
+    private static void handleS4U2SelfReferral(PAData[] pas,
+            PrincipalName user, Credentials newCreds)
+                    throws Asn1Exception, KrbException, IOException {
+        if (DEBUG) {
+            System.out.println(">>> Handling S4U2Self referral");
+        }
+        for (int i = 0; i < pas.length; i++) {
+            PAData pa = pas[i];
+            if (pa.getType() == Krb5.PA_FOR_USER) {
+                pas[i] = new PAData(Krb5.PA_FOR_USER,
+                        new PAForUserEnc(user,
+                                newCreds.getSessionKey()).asn1Encode());
+                break;
+            }
+        }
+    }
+
+    /**
+     * This method is called after receiving the first realm referral for
+     * a S4U2Proxy request. The credentials and tickets needed for the
+     * final S4U2Proxy request (in the referrals chain) are returned.
+     *
+     * Referrals are handled as described by MS-SFU (section 3.1.5.2.2
+     * Receives Referral).
+     *
+     * @param asCreds middle service credentials used for the first S4U2Proxy
+     *        request
+     * @param credsInOut (in/out parameter):
+     *         * input: first S4U2Proxy referral TGT received, null
+     *         * output: referral TGT for final S4U2Proxy service request,
+     *                   client referral TGT for final S4U2Proxy service request
+     *                   (to be sent as additional-ticket)
+     * @param sname the backend service name
+     * @param additionalTickets (out parameter): the additional ticket for the
+     *        last S4U2Proxy request is returned
+     * @return the backend realm for the last S4U2Proxy request
+     */
+    private static String handleS4U2ProxyReferral(Credentials asCreds,
+            Credentials[] credsInOut, PrincipalName sname)
+                    throws KrbException, IOException {
+        if (DEBUG) {
+            System.out.println(">>> Handling S4U2Proxy referral");
+        }
+        Credentials refTGT = null;
+        // Get a credential for the middle service to the backend so we know
+        // the backend realm, as described in MS-SFU (section 3.1.5.2.2).
+        Credentials middleSvcCredsInBackendRealm =
+                serviceCreds(sname, asCreds);
+        String backendRealm =
+                middleSvcCredsInBackendRealm.getServer().getRealmString();
+        String toRealm = credsInOut[0].getServer().getNameStrings()[1];
+        if (!toRealm.equals(backendRealm)) {
+            // More than 1 hop. Follow the referrals chain and obtain a
+            // TGT for the backend realm.
+            refTGT = getTGTforRealm(toRealm, backendRealm, credsInOut[0],
+                    new boolean[1]);
+        } else {
+            // There was only 1 hop. The referral TGT received is already
+            // for the backend realm.
+            refTGT = credsInOut[0];
+        }
+        credsInOut[0] = getTGTforRealm(asCreds.getClient().getRealmString(),
+                backendRealm, asCreds, new boolean[1]);
+        credsInOut[1] = refTGT;
+        return backendRealm;
+    }
 }
