@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,11 +150,15 @@ public class FormatData_mi extends ListResourceBundle {
                "HW3",
                "HW4",
             };
+        final String[] metaValue_long_Eras = new String[] {
+               "BCE",
+               "CE",
+            };
         final String[] metaValue_TimePatterns = new String[] {
                "h:mm:ss a zzzz",
                "h:mm:ss a z",
-               "h:mm:ss",
-               "h:mm",
+               "h:mm:ss a",
+               "h:mm a",
             };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
@@ -166,39 +166,49 @@ public class FormatData_mi extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "G y MMMM d, EEEE",
-               "G y MMMM d",
-               "G y MMM d",
-               "GGGGG y-MM-dd",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "GGGG y MMMM d, EEEE",
-               "GGGG y MMMM d",
-               "GGGG y MMM d",
-               "G y-MM-dd",
-            };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
+        final String[] metaValue_buddhist_AmPmMarkers = new String[] {
                "AM",
                "PM",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
+               "EEEE, d MMMM y G",
+               "d MMMM y G",
+               "d MMM y G",
+               "dd-MM-y GGGGG",
+            };
+        final String[] metaValue_buddhist_DatePatterns = new String[] {
+               "EEEE, d MMMM y GGGG",
+               "d MMMM y GGGG",
+               "d MMM y GGGG",
+               "dd-MM-y G",
             };
         final String metaValue_calendarname_gregorian = "Maramataka P\u0101keh\u0101";
         final String[] metaValue_short_CompactNumberPatterns = new String[] {
                "",
                "",
                "",
-               "0K",
-               "00K",
-               "000K",
-               "0M",
-               "00M",
-               "000M",
-               "0G",
-               "00G",
-               "000G",
-               "0T",
-               "00T",
-               "000T",
+               "{other:0K}",
+               "{other:00K}",
+               "{other:000K}",
+               "{other:0M}",
+               "{other:00M}",
+               "{other:000M}",
+               "{other:0G}",
+               "{other:00G}",
+               "{other:000G}",
+               "{other:0T}",
+               "{other:00T}",
+               "{other:000T}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -206,7 +216,8 @@ public class FormatData_mi extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -215,13 +226,17 @@ public class FormatData_mi extends ListResourceBundle {
             { "field.zone", "rohe w\u0101" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "narrow.Eras", metaValue_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -248,6 +263,8 @@ public class FormatData_mi extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -257,10 +274,12 @@ public class FormatData_mi extends ListResourceBundle {
             { "field.minute", "meneti" },
             { "field.era", "w\u0101" },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
@@ -273,29 +292,22 @@ public class FormatData_mi extends ListResourceBundle {
             { "field.week", "wiki" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4\u00a0#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "DatePatterns",
                 new String[] {
-                    "y MMMM d, EEEE",
-                    "y MMMM d",
-                    "y MMM d",
-                    "y-MM-dd",
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "d MMM y",
+                    "dd-MM-y",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
@@ -303,14 +315,22 @@ public class FormatData_mi extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "h\u0101ora" },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4\u00a0#,##0.00",
+                    "#,##0%",
+                    "\u00a4\u00a0#,##0.00",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_buddhist_AmPmMarkers },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
