@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -88,10 +84,44 @@ public class FormatData_pt_PT extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "da manh\u00e3",
                "da tarde",
+               "meia-noite",
+               "meio-dia",
+               "da manh\u00e3",
+               "",
+               "da tarde",
+               "",
+               "da noite",
+               "",
+               "da madrugada",
+               "",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "a.m.",
                "p.m.",
+               "meia-noite",
+               "meio-dia",
+               "manh\u00e3",
+               "",
+               "tarde",
+               "",
+               "noite",
+               "",
+               "madrugada",
+               "",
+            };
+        final String[] metaValue_abbreviated_AmPmMarkers = new String[] {
+               "a.m.",
+               "p.m.",
+               "meia-noite",
+               "meio-dia",
+               "da manh\u00e3",
+               "",
+               "da tarde",
+               "",
+               "da noite",
+               "",
+               "da madrugada",
+               "",
             };
         final String metaValue_timezone_regionFormat_daylight = "Hora padr\u00e3o de {0}";
         final String[] metaValue_TimePatterns = new String[] {
@@ -132,15 +162,15 @@ public class FormatData_pt_PT extends ListResourceBundle {
             { "calendarname.islamic-civil", "Calend\u00e1rio isl\u00e2mico (civil)" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "timezone.regionFormat.standard", metaValue_timezone_regionFormat_daylight },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "calendarname.japanese", "Calend\u00e1rio japon\u00eas" },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "DateTimePatterns",
                 new String[] {
@@ -215,6 +245,7 @@ public class FormatData_pt_PT extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "PluralRules", "one:i = 1 and v = 0" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "calendarname.buddhist", "Calend\u00e1rio budista" },
@@ -251,7 +282,7 @@ public class FormatData_pt_PT extends ListResourceBundle {
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterNames },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
