@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -198,7 +194,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "DE", "\u0c1c\u0c30\u0c4d\u0c2e\u0c28\u0c40" },
             { "goh", "\u0c2a\u0c4d\u0c30\u0c3e\u0c1a\u0c40\u0c28 \u0c39\u0c48 \u0c1c\u0c30\u0c4d\u0c2e\u0c28\u0c4d" },
             { "ace", "\u0c06\u0c16\u0c3f\u0c28\u0c40\u0c38\u0c4d" },
-            { "cgg", "\u0c1b\u0c3f\u0c17\u0c3e" },
+            { "cgg", "\u0c1a\u0c3f\u0c17\u0c3e" },
             { "DG", "\u0c21\u0c3f\u0c2f\u0c3e\u0c17\u0c4b \u0c17\u0c3e\u0c30\u0c4d\u0c38\u0c3f\u0c2f\u0c3e" },
             { "type.nu.deva", "\u0c26\u0c47\u0c35\u0c28\u0c3e\u0c17\u0c30\u0c3f \u0c05\u0c02\u0c15\u0c46\u0c32\u0c41" },
             { "DJ", "\u0c1c\u0c3f\u0c2c\u0c4c\u0c1f\u0c3f" },
@@ -259,7 +255,6 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "FR", "\u0c2b\u0c4d\u0c30\u0c3e\u0c28\u0c4d\u0c38\u0c4d\u200c" },
             { "tkl", metaValue_TK },
             { "grb", "\u0c17\u0c4d\u0c30\u0c47\u0c2c\u0c4b" },
-            { "root", "\u0c30\u0c42\u0c1f\u0c4d" },
             { "type.ca.indian", "\u0c2d\u0c3e\u0c30\u0c24\u0c40\u0c2f \u0c1c\u0c3e\u0c24\u0c40\u0c2f \u0c15\u0c4d\u0c2f\u0c3e\u0c32\u0c46\u0c02\u0c21\u0c30\u0c4d" },
             { "grc", "\u0c2a\u0c4d\u0c30\u0c3e\u0c1a\u0c40\u0c28 \u0c17\u0c4d\u0c30\u0c40\u0c15\u0c4d" },
             { "GA", "\u0c17\u0c47\u0c2c\u0c28\u0c4d" },
@@ -762,7 +757,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "type.lb.normal", "\u0c38\u0c3e\u0c27\u0c3e\u0c30\u0c23 \u0c32\u0c48\u0c28\u0c4d \u0c2c\u0c4d\u0c30\u0c47\u0c15\u0c4d \u0c36\u0c48\u0c32\u0c3f" },
             { "ro_MD", "\u0c2e\u0c4a\u0c32\u0c4d\u0c21\u0c3e\u0c35\u0c3f\u0c2f\u0c28\u0c4d" },
             { "el", metaValue_el },
-            { "en", "\u0c06\u0c02\u0c17\u0c4d\u0c32\u0c02" },
+            { "en", "\u0c07\u0c02\u0c17\u0c4d\u0c32\u0c40\u0c37\u0c4d" },
             { "eo", "\u0c0e\u0c38\u0c4d\u0c2a\u0c46\u0c30\u0c3e\u0c02\u0c1f\u0c4b" },
             { "type.co.big5han", "\u0c38\u0c3e\u0c02\u0c2a\u0c4d\u0c30\u0c26\u0c3e\u0c2f \u0c1a\u0c48\u0c28\u0c40\u0c38\u0c4d \u0c15\u0c4d\u0c30\u0c2e\u0c2c\u0c26\u0c4d\u0c27\u0c40\u0c15\u0c30\u0c23 \u0c15\u0c4d\u0c30\u0c2e\u0c02 - Big5" },
             { "es", "\u0c38\u0c4d\u0c2a\u0c3e\u0c28\u0c3f\u0c37\u0c4d" },
@@ -1148,6 +1143,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0c24\u0c2e\u0c3f\u0c33 \u0c05\u0c02\u0c15\u0c46\u0c32\u0c41" },
             { "krc", "\u0c15\u0c30\u0c1a\u0c47-\u0c2c\u0c32\u0c4d\u0c15\u0c3e\u0c30\u0c4d" },
             { "inh", "\u0c07\u0c02\u0c17\u0c41\u0c37\u0c4d" },
+            { "fa_AF", "\u0c21\u0c3e\u0c30\u0c3f" },
             { "krl", "\u0c15\u0c30\u0c47\u0c32\u0c3f\u0c2f\u0c28\u0c4d" },
             { "efi", "\u0c0e\u0c2b\u0c3f\u0c15\u0c4d" },
             { "tcy", "\u0c24\u0c41\u0c33\u0c41" },
