@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -248,15 +244,15 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "MA", "Marokko" },
             { "MC", "Monako" },
             { "MD", "Moldowa" },
-            { "ME", "Montenegro" },
+            { "ME", "\u00c7ernogori\u00fda" },
             { "MF", "Sen-Marten" },
             { "MG", "Madagaskar" },
             { "MH", "Mar\u015fall adalary" },
             { "MK", "Demirgazyk Makedoni\u00fda" },
             { "ML", "Mali" },
-            { "MM", "M\u00fdanma (Burma)" },
+            { "MM", "M\u00fdanma (Birma)" },
             { "MN", "Mongoli\u00fda" },
-            { "MO", "Makau AAS Hyta\u00fd" },
+            { "MO", "Makao AAS Hyta\u00fd" },
             { "MP", "Demirgazyk Mariana adalary" },
             { "MQ", "Martinika" },
             { "MR", "Mawritani\u00fda" },
@@ -322,7 +318,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "SV", "Salwador" },
             { "SX", "Sint-Marten" },
             { "SY", "Siri\u00fda" },
-            { "SZ", "Swazilend" },
+            { "SZ", "Eswatini" },
             { "TA", "Tristan-da-Kun\u00fda" },
             { "TC", "Terks we Ka\u00fdkos adalary" },
             { "TD", "\u00c7ad" },
@@ -384,7 +380,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "bn", "bengal dili" },
             { "bo", "tibet dili" },
             { "br", "breton dili" },
-            { "bs", "bo\u015fnak dili" },
+            { "bs", "bosni\u00fda dili" },
             { "ca", "katalan dili" },
             { "ce", "\u00e7e\u00e7en dili" },
             { "ch", "\u00e7amorro" },
@@ -456,7 +452,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "ln", "lingala dili" },
             { "lo", "laos dili" },
             { "lt", "litwa dili" },
-            { "lu", "luba-Katanga dili" },
+            { "lu", "luba-katanga dili" },
             { "lv", "laty\u015f dili" },
             { "mg", "malagasi\u00fd dili" },
             { "mh", "mar\u015fall dili" },
@@ -506,7 +502,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "sq", "alban dili" },
             { "sr", "serb dili" },
             { "ss", "swati dili" },
-            { "st", "g\u00fcnorta Soto dili" },
+            { "st", "g\u00fcnorta soto dili" },
             { "su", "sundan dili" },
             { "sv", "\u015fwed dili" },
             { "sw", "suahili dili" },
@@ -576,7 +572,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "dje", "zarma dili" },
             { "dsb", "a\u015faky lu\u017eits dili" },
             { "dua", "duala dili" },
-            { "dyo", "\u00fdola-Fonyi dili" },
+            { "dyo", "\u00fdola-fon\u00fdi dili" },
             { "dzg", "daza dili" },
             { "ebu", "embu dili" },
             { "efi", "efik dili" },
@@ -614,7 +610,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "kea", "kabuwerdianu dili" },
             { "kfo", "koro dili" },
             { "kha", "khasi dili" },
-            { "khq", "ko\u00fdra-\u00c7ini dili" },
+            { "khq", "ko\u00fdra-\u00e7ini dili" },
             { "kkj", "kako dili" },
             { "kln", "kalenjin dili" },
             { "kmb", "kimbundu dili" },
@@ -647,7 +643,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "men", "mende dili" },
             { "mer", "meru dili" },
             { "mfe", "moris\u00fden dili" },
-            { "mgh", "makua-Mitto dili" },
+            { "mgh", "makuwa-mito dili" },
             { "mgo", "meta dili" },
             { "mic", "mikmak dili" },
             { "min", "minangkabau dili" },
@@ -677,7 +673,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "pam", "kapampangan dili" },
             { "pap", "pap\u00fdamento dili" },
             { "pau", "palau dili" },
-            { "pcm", "nigeri\u00fd-pijin dili" },
+            { "pcm", "nigeri\u00fda-pijin dili" },
             { "prg", "prussi\u00fda dili" },
             { "quc", "ki\u00e7e dili" },
             { "rap", "rapanu\u00fd dili" },
@@ -694,7 +690,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "scn", "sisili\u00fda dili" },
             { "sco", "\u015fotland dili" },
             { "seh", "sena dili" },
-            { "ses", "ko\u00fdraboro-Senni dili" },
+            { "ses", "ko\u00fdraboro-senni dili" },
             { "shi", "tahelhit dili" },
             { "shn", "\u015fan dili" },
             { "sma", "g\u00fcnorta saam dili" },
@@ -718,7 +714,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "tvl", "tuwalu dili" },
             { "twq", "tasawak dili" },
             { "tyv", "tuwa dili" },
-            { "tzm", "orta-Atlas tamazight dili" },
+            { "tzm", "orta-atlas tamazight dili" },
             { "udm", "udmurt dili" },
             { "umb", "umbundu dili" },
             { "und", "n\u00e4belli dil" },
@@ -780,11 +776,11 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "Zxxx", "\u00ddazuwsyz" },
             { "Zyyy", "Umumy" },
             { "Zzzz", "N\u00e4belli elipbi\u00fd" },
-            { "root", "k\u00f6k" },
             { "de_CH", "\u00fdokarky nemes dili (\u015ewe\u00fdsari\u00fda)" },
             { "en_GB", "i\u0148lis dili (Be\u00fdik Britani\u00fda)" },
             { "en_US", "i\u0148lis dili (Amerika)" },
             { "es_ES", "ispan dili (\u00ddewropa)" },
+            { "fa_AF", "dari dili" },
             { "nl_BE", "flamand dili" },
             { "pt_PT", "portugal dili (\u00ddewropa)" },
             { "ro_MD", "moldaw dili" },
